@@ -25,6 +25,7 @@ import logging
 import traceback
 import json
 import sys
+import abc
 
 from arjuna.tpi.constant import *
 from arjuna.core.constant import *
@@ -64,10 +65,6 @@ class MainCommand(Command):
         super().__init__()
         parser = argparse.ArgumentParser(prog='python -m arjuna', conflict_handler='resolve',
                                 description="This is the CLI of Arjuna. Use the appropriate command and sub-commands as needed.")
-        parser.add_argument('-dl', '--display-level', dest='log.console.level', type=ustr, choices=[i for i in LoggingLevel.__members__],
-                                 help="Minimum message level for display. (choose from 'DEBUG', 'INFO', 'WARN', 'ERROR', 'FATAL')", default=LoggingLevel.INFO.name)
-        parser.add_argument('-ll', '--log-level', dest='log.file.level', type=ustr, choices=[i for i in LoggingLevel.__members__],
-                                 help="Minimum message level for log file. (choose from 'DEBUG', 'INFO', 'WARN', 'ERROR', 'FATAL')", default=LoggingLevel.DEBUG.name)
         self._set_parser(parser)
 
     def create_subparsers(self):
@@ -75,12 +72,14 @@ class MainCommand(Command):
 
     def convert_to_dict(self, args):
         def format_value(k, v):
-            if k in {"ao", "uo"}:
-                return v
-            if type(v) is list:
-                return ",".join([str(i) for i in v])
-            else:
-                return v
+            # if k in {"ao", "uo", "irules", "erules", 'ip', 'ep', }:
+            #     return v
+            if k == "report.formats" and v is None:
+                v = ['XML', 'HTML']
+            # if type(v) is list:
+            #     return ",".join([str(i) for i in v])
+            # else:
+            return v
         try:
             args = self.parser.parse_args(args[1:])
             return {k:format_value(k,v) for k,v in vars(args).items()}
@@ -90,6 +89,8 @@ class MainCommand(Command):
             import traceback
             traceback.print_exc()
             sys_utils.fexit()
+        import sys
+        sys.exit(1)
 
     def execute(self, arg_dict):
         pass
@@ -104,8 +105,6 @@ class CreateProject(Command):
 
     COMMON_DIRS_FILES = (
         (FileObjectType.DIR, "config"),
-        (FileObjectType.DIR, "config/env"),
-        (FileObjectType.DIR, "config/run"),
         (FileObjectType.FILE, "config/data.yaml"),
         (FileObjectType.FILE, "config/envs.yaml"),
         (FileObjectType.FILE, "config/groups.yaml"),
@@ -127,19 +126,21 @@ class CreateProject(Command):
         (FileObjectType.DIR, "guiauto/driver/mac"),
         (FileObjectType.DIR, "guiauto/driver/windows"),
         (FileObjectType.DIR, "guiauto/namespace"),
+        (FileObjectType.DIR, "hook"),
+        (FileObjectType.FILE, "hook/arjuna_config.py"),
         (FileObjectType.DIR, "report"),
         (FileObjectType.DIR, "script"),
         (FileObjectType.DIR, "test"),
         (FileObjectType.FILE, "test/__init__.py"),
-        (FileObjectType.DIR, "test/module"),
-        (FileObjectType.FILE, "test/module/__init__.py"),
+        (FileObjectType.DIR, "test/pkg"),
+        (FileObjectType.FILE, "test/pkg/__init__.py"),
         (FileObjectType.DIR, "lib"),
         (FileObjectType.FILE, "lib/__init__.py"),
-        (FileObjectType.DIR, "lib/fixture"),
-        (FileObjectType.FILE, "lib/fixture/__init__.py"),
-        (FileObjectType.FILE, "lib/fixture/session.py"),
-        (FileObjectType.FILE, "lib/fixture/module.py"),
-        (FileObjectType.FILE, "lib/fixture/test.py"),
+        (FileObjectType.DIR, "lib/resource"),
+        (FileObjectType.FILE, "lib/resource/__init__.py"),
+        (FileObjectType.FILE, "lib/resource/group.py"),
+        (FileObjectType.FILE, "lib/resource/module.py"),
+        (FileObjectType.FILE, "lib/resource/test.py"),
     )
 
     def __init__(self, subparsers, parents):
@@ -180,7 +181,7 @@ class CreateProject(Command):
             for ftype, frpath in CreateProject.COMMON_DIRS_FILES:
                 self.__create_file_or_dir(project_temp_dir, ftype, frpath)
             copy_file("../../res/project.yaml", "config/project.yaml")
-            copy_file("../../res/check_dummy.py", "test/module/check_dummy.py")
+            copy_file("../../res/check_dummy.py", "test/pkg/check_dummy.py")
             copy_file("../../res/arjuna_launcher.py", "script/arjuna_launcher.py")
             f = open(get_src_file_path("../../res/conftest.txt"), "r")
             contents = f.read().format(project=project_name)
@@ -219,10 +220,13 @@ class __RunCommand(Command):
         runid = arg_dict.pop("run.id")
         static_rid = arg_dict.pop("static.rid")
         self.dry_run = arg_dict.pop("dry_run")
-        if "group.conf.name" in arg_dict:
-            self.group_conf_name = arg_dict.pop("group.conf.name")
-        else:
-            self.group_conf_name = None
+        if self.dry_run:
+            self.dry_run = DryRunType[self.dry_run]
+        
+        if "ref_conf" in arg_dict:
+            self.ref_conf_name = arg_dict.pop("ref_conf")
+
+        self.pop_command_args(arg_dict)
 
         Arjuna.init(project_root_dir, CliArgsConfig(arg_dict), runid, static_rid=static_rid)
 
@@ -233,71 +237,90 @@ class __RunCommand(Command):
         py_3rdparty_dir = Arjuna.get_config().value(ArjunaOption.ARJUNA_EXTERNAL_IMPORTS_DIR)
         sys.path.append(py_3rdparty_dir)
 
+    def pop_command_args(self, arg_dict):
+        pass
+
 
 class RunProject(__RunCommand):
     def __init__(self, subparsers, parents):
         super().__init__(subparsers, 'run-project', parents, "Run all tests in an Arjuna Test Project in a single thread.")
+        self.ref_conf_name = None
 
     def execute(self, arg_dict):
         super().execute(arg_dict)
         from arjuna import Arjuna
         session = Arjuna.get_test_session()
-        session.load_tests(dry_run=self.dry_run, group_conf_name=self.group_conf_name)
+        session.load_tests(dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
         session.run()
 
+
 class RunSession(__RunCommand):
     def __init__(self, subparsers, parents):
-        super().__init__(subparsers, 'run-session', parents, "Run tests as per the session configuration file.")
+        super().__init__(subparsers, 'run-session', parents, "Run tests as per the named test session definition in sessions.yaml.")
 
     def execute(self, arg_dict):
         super().execute(arg_dict)
         from arjuna import Arjuna
         session = Arjuna.get_test_session()
-        session.load_tests(dry_run=self.dry_run, group_conf_name=self.group_conf_name)
+        session.load_tests(dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
         session.run()
 
+class RunStage(__RunCommand):
+    def __init__(self, subparsers, parents):
+        super().__init__(subparsers, 'run-stage', parents, "Run tests as per the named test stage definition in stages.yaml.")
+        self.__stage_name = None
+
+    def execute(self, arg_dict):
+        super().execute(arg_dict)
+        from arjuna import Arjuna
+        session = Arjuna.get_test_session()
+        session.load_tests_for_stage(stage_name=self.__stage_name, dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
+        session.run()
+
+    def pop_command_args(self, arg_dict):
+        self.__stage_name = arg_dict.pop("stage_name")
+
+class RunGroup(__RunCommand):
+    def __init__(self, subparsers, parents):
+        super().__init__(subparsers, 'run-group', parents, "Run tests as per the named test group definition in groups.yaml.")
+        self.__group_name = None
+
+    def execute(self, arg_dict):
+        super().execute(arg_dict)
+        from arjuna import Arjuna
+        session = Arjuna.get_test_session()
+        session.load_tests_for_group(group_name=self.__group_name, dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
+        session.run()
+
+    def pop_command_args(self, arg_dict):
+        self.__group_name = arg_dict.pop("group_name")
+
+
 class RunSelected(__RunCommand):
 
     def __init__(self, subparsers, parents):
         super().__init__(subparsers, 'run-selected', parents, "Run tests selected based on selectors specified in a single thread.")
+        self.ref_conf_name = None
+        self.__pickers_dict = dict()
+        self.__rules = {'ir': [], 'er': []}
 
     def execute(self, arg_dict):
-        pickers_dict = dict()
-        pickers = (
-            ('imodules', 'im'),
-            ('emodules', 'em'),
-            # ('cclasses', 'cc'),
-            # ('iclasses', 'ic'),
-            ('itests', 'it'),
-            ('etests', 'et'),
-            )
-
-        def process_picker(sname, tname):
-            if sname in arg_dict:
-                val = arg_dict.pop(sname)
-                if not val: 
-                    pickers_dict[tname] = list()
-                    return
-                pickers_dict[tname] = val.split(",")
-            else:
-                pickers_dict[tname] = list()
-
-        def remove_py_ext(name):
-            if not name.lower().endswith(".py"):
-                return name
-            else:
-                return name.replace(".py","")
-
-        for picker in pickers:
-            process_picker(picker[0], picker[1])
-
-        pickers_dict['im'] = [remove_py_ext(m) for m in pickers_dict['im']]
-        pickers_dict['em'] = [remove_py_ext(m) for m in pickers_dict['em']]
-
         super().execute(arg_dict)
 
         from arjuna import Arjuna
         session = Arjuna.get_test_session()
-        session.load_tests(**pickers_dict, dry_run=self.dry_run, group_conf_name=self.group_conf_name)
+        session.load_tests(rules=self.__rules, dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
         session.run()
 
+    def pop_command_args(self, arg_dict):
+        from arjuna.engine.session.group import TestGroup
+        i_e_rules = TestGroup.create_rule_strs(arg_dict)
+        self.__rules['ir'].extend(i_e_rules['ir'])
+        self.__rules['er'].extend(i_e_rules['er'])
+        irule_strs = arg_dict.pop('ir')
+        if irule_strs:
+            self.__rules['ir'].extend(irule_strs)
+        erule_strs = arg_dict.pop('er')
+        if erule_strs:
+            self.__rules['er'].extend(erule_strs)
+
